@@ -1,6 +1,6 @@
 #' Framework7 preloader
 #'
-#' Deprecated. \link{f7ShowPreloader} shows a preloader.
+#' \code{showF7Preloader} shows a preloader.
 #'
 #' @param target Element where preloader overlay will be added.
 #' @param color Preloader color.
@@ -42,7 +42,7 @@
 #'     })
 #'
 #'     observeEvent(input$showLoader, {
-#'       f7ShowPreloader(color = "red")
+#'       showF7Preloader(color = "red")
 #'       Sys.sleep(2)
 #'       f7HidePreloader()
 #'     })
@@ -81,24 +81,16 @@
 #'     })
 #'
 #'     observeEvent(input$obs, {
-#'       f7ShowPreloader(target = "#distPlot", color = "red")
+#'       showF7Preloader(target = "#distPlot", color = "red")
 #'       Sys.sleep(2)
 #'       f7HidePreloader()
 #'     })
 #'   }
 #'  )
 #' }
-f7ShowPreloader <- function(target = NULL, color = NULL,
+showF7Preloader <- function(target = NULL, color = NULL,
                             session = shiny::getDefaultReactiveDomain()) {
 
-  .Deprecated(
-    "showF7Preloader",
-    package = "shinyMobile",
-    "f7ShowPreloader will be removed in future release. Please use
-    showF7Preloader instead.",
-    old = as.character(sys.call(sys.parent()))[1L]
-  )
-
   message <- dropNulls(list(el = target, color = color))
   session$sendCustomMessage('show-preloader', message)
 }
@@ -106,33 +98,36 @@ f7ShowPreloader <- function(target = NULL, color = NULL,
 
 #' Framework7 preloader
 #'
-#' \link{showF7Preloader} shows a preloader.
+#' \code{f7ShowPreloader} shows a preloader.
+#' Use \link{showF7Preloader} instead
+#'
+#' @inheritParams showF7Preloader
+#' @rdname f7-deprecated
+#' @keywords internal
 #'
-#' @param target Element where preloader overlay will be added.
-#' @param color Preloader color.
-#' @param session Shiny session object.
 #' @export
-#' @rdname preloader
-showF7Preloader <- f7ShowPreloader
+f7ShowPreloader <- function(target = NULL, color = NULL,
+                            session = shiny::getDefaultReactiveDomain()){
+  .Deprecated(
+    "showF7Preloader",
+    package = "shinyMobile",
+    "f7ShowPreloader will be removed in future release. Please use
+      showF7Preloader instead.",
+    old = as.character(sys.call(sys.parent()))[1L]
+  )
+}
 
 
 #' Framework7 preloader
 #'
-#' Deprecated. \link{f7HidePreloader} hides a preloader.
+#' \code{f7HidePreloader} hides a preloader.
 #'
 #' @param target Element where preloader overlay will be added.
 #' @param session Shiny session object.
 #' @export
 #' @rdname preloader
-f7HidePreloader <- function(target = NULL, session = shiny::getDefaultReactiveDomain()) {
-
-  .Deprecated(
-    "hideF7Preloader",
-    package = "shinyMobile",
-    "f7HidePreloader will be removed in future release. Please use
-    hideF7Preloader instead.",
-    old = as.character(sys.call(sys.parent()))[1L]
-  )
+f7HidePreloader <- function(target = NULL,
+                            session = shiny::getDefaultReactiveDomain()) {
 
   message <- dropNulls(list(el = target))
   session$sendCustomMessage('hide-preloader', message)
@@ -142,10 +137,21 @@ f7HidePreloader <- function(target = NULL, session = shiny::getDefaultReactiveDo
 
 #' Framework7 preloader
 #'
-#' \link{hideF7Preloader} hides a preloader.
+#' \code{hideF7Preloader} hides a preloader.
+#' Use \link{f7HidePreloader} instead
 #'
-#' @param target Element where preloader overlay will be added.
-#' @param session Shiny session object.
+#' @inheritParams  hideF7Preloader
+#' @rdname f7-deprecated
+#' @keywords internal
 #' @export
-#' @rdname preloader
-hideF7Preloader <- f7HidePreloader
+hideF7Preloader <- function(target = NULL,
+                            session = shiny::getDefaultReactiveDomain()) {
+  .Deprecated(
+    "hideF7Preloader",
+    package = "shinyMobile",
+    "f7HidePreloader will be removed in future release. Please use
+      hideF7Preloader instead.",
+    old = as.character(sys.call(sys.parent()))[1L])
+    f7HidePreloader(target, session)
+}
+
