@@ -11,10 +11,10 @@ add_pwa_deps <- function(tag) {
  pwa_deps <- htmlDependency(
   name = "pwa-utils",
   version = packageVersion("shinyMobile"),
-  src = c(file = "shinyMobile-0.8.0.9000"),
-  head = "<link rel=\"manifest\" href=\"manifest.webmanifest\"  />
+  src = c(file = "shinyMobile-0.9.0"),
+  head = "<link rel=\"manifest\" href=\"manifest.webmanifest\" />
 <link rel=\"icon\" type=\"image/png\" href=\"icons/icon-144.png\" sizes=\"144x144\" />
-<link rel=\"apple-touch-icon\" href=\"icons/apple-touch-icon.png\"/>
+<link rel=\"apple-touch-icon\" href=\"icons/apple-touch-icon.png\" />
 <link rel=\"icon\" href=\"icons/favicon.png\"/>
   ",
   package = "shinyMobile",
